@@ -65,23 +65,14 @@ class Storage(driver.Base):
     def put_content(self, path, content):
         logger.info("put_content path:%s" % path)
         logger.info("-------------------------------------->%s" % content)
-        self.put_store(path, content)
-        return path
-    
-    def put_store(self, path, content, chunk=None, length=None):
-        logger.info("put_store path:%s" % path)
-        logger.info("put_store-------------------------------------->%s" % content)
         path1 = self._init_path(path)
         try:
-            headers = {}
-            if length is not None:
-                headers["Content-Length"] = str(length)
-                
             object_instance = self._jss.bucket(self._bucket).object(path1)
-            object_instance.upload_flow(None, headers, content)
+            object_instance.upload_flow(None, None, content)
         except Exception as e:
             logger.error("put_content error:%s" % e)
             raise e
+        return path
 
 
     def stream_write(self, path, fp):
